@@ -17,7 +17,7 @@
 QTEST_MAIN(AddressTest)
 void initLocale()
 {
-    qputenv("LANG", "it_CH");
+    qputenv("LANG", "it_CH.UTF-8");
     QLocale::setDefault(QLocale(QLocale::Italian, QLocale::Switzerland));
 }
 
